/***************************************************************************
                     bluetoothsettings.cpp  -  description
                             -------------------
    begin                : Fri Dec 13 2002
    copyright            : (C) 2002 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "bluetoothsettings.h"

#include <qspinbox.h>
#include <qlineedit.h>

#include <kapp.h>
#include <kconfig.h>

const char* const BluetoothSettings::configGroup = "Bluetooth Settings";
const char* const BluetoothSettings::configChannel = "Channel";
const char* const BluetoothSettings::configAddress = "Address";
const char* const BluetoothSettings::configAddressDefault = "00:00:00:00:00:00";

BluetoothSettings::BluetoothSettings(QWidget *parent, const char *name) : BluetoothSettingsBase(parent, name) {

	// Read and restore settings from config file
	kapp->config()->setGroup(configGroup);
	channel->setValue(kapp->config()->readNumEntry(configChannel, configChannelDefault));
	address->setText(kapp->config()->readEntry(configAddress, configAddressDefault));

	// Connect everything
	connect(address, SIGNAL(textChanged(const QString&)), this, SLOT(slotAddress(const QString&)));
	connect(channel, SIGNAL(valueChanged(int)), this, SLOT(slotChannel(int)));
}

BluetoothSettings::~BluetoothSettings() {
}

void BluetoothSettings::slotAddress(const QString& address) {
	kapp->config()->setGroup(configGroup);
	kapp->config()->writeEntry(configAddress, address);

	emit settingsChanged();
}

void BluetoothSettings::slotChannel(int value) {
	kapp->config()->setGroup(configGroup);
	kapp->config()->writeEntry(configChannel, value);

	emit settingsChanged();
}

