/***************************************************************************
                          deviceinfo.cpp  -  description
                             -------------------
    begin                : Fri Jan 24 2003
    copyright            : (C) 2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "deviceinfo.h"

#include <qpushbutton.h>
#include <qstringlist.h>

#include <kmessagebox.h>
#include <ksqueezedtextlabel.h>

DeviceInfo::DeviceInfo(QObex* o, QWidget *parent, const char *name ) : DeviceInfoBase(parent,name), obex(o) {

	// Connect signal/slot for click on send button
	connect(getButton, SIGNAL(clicked()), this, SLOT(slotGet()));
}

DeviceInfo::~DeviceInfo(){
}

void DeviceInfo::setObex(QObex* o) {
	obex = o;
}

void DeviceInfo::slotGet() {

	// Disable button
	getButton->setEnabled(false);

	// Clear current data
	manufacturer->clear();
	model->clear();
	hardwareVersion->clear();
	softwareVersion->clear();
	softwareDate->clear();
	serialNumber->clear();
	
    // Create client to perform push
    client = new QObexClientGet(*obex, "telecom/devinfo.txt");

    connect(client, SIGNAL(error(const QString&)), this, SLOT(slotClientError(const QString&)));
	connect(client, SIGNAL(done()), this, SLOT(slotClientDone()));
	connect(client, SIGNAL(data(QByteArray&)), this, SLOT(slotClientData(QByteArray&)));

	// Start get
	client->start();
}

void DeviceInfo::slotClientError(const QString& msg) {
    KMessageBox::error(this, msg);
}

void DeviceInfo::slotClientDone() {
	client->deleteLater();

	// Re-enable button
	getButton->setEnabled(true);
}

void DeviceInfo::slotClientData(QByteArray& data) {

	// Create string from data
	QString info(data);

    // Create list from data
	QStringList list = QStringList::split("\r\n", info);

	// Iterate through list looking for data we want
	// Not the most efficient method i'm sure
	QString key, value;
    for(QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
		key = (*it).section(":", 0, 0);
		value = (*it).section(":", 1);

        if(key == "MANU")
			manufacturer->setText(value);
		else if(key == "MOD")
			model->setText(value);
		else if(key == "SW-VERSION")
			softwareVersion->setText(value);
		else if(key == "SW-DATE")
			softwareDate->setText(value);
		else if(key == "HW-VERSION")
			hardwareVersion->setText(value);
		else if(key == "SN")
			serialNumber->setText(value);
    }
}
