/***************************************************************************
                          k68.cpp  -  description
                             -------------------
    begin                : Sat Nov  9 18:56:38 GMT 2002
    copyright            : (C) 2002-2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef HAVE_BLUETOOTH
#include <bluetooth/bluetooth.h>
#endif

#include "k68.h"

#include "sendfile.h"
#include "settings.h"
#include "serialcablesettings.h"
#include "qobexserialcable.h"
#include "infraredsettings.h"
#include "qobexinfrared.h"
#include "bluetoothsettings.h"
#include "qobexbluetooth.h"


#include <qpushbutton.h>
#include <qvbox.h>
#include <qlineedit.h>

#include <kglobal.h>
#include <kicontheme.h>
#include <kiconloader.h>
#include <kjanuswidget.h>
#include <klocale.h>
#include <kconfig.h>
#include <khelpmenu.h>
#include <kpopupmenu.h>
#include <kaction.h>

K68::K68(QWidget *parent, const char *name)
	: KDialogBase(IconList, NULL, Help|Close, Ok, parent, name, false, true),
	  settingsChanged(false)
{
   	// Create obex instance
	obex = createObex();

    // Make sure there's no scroll bar on the icon panel
  	setIconListAllVisible(true);

	// Add pages
	QVBox *sendPageBox = addVBoxPage(i18n("Send File"), i18n("Send File To Phone"), KGlobal::iconLoader()->loadIcon("forward", KIcon::NoGroup, 32) );
    QVBox *infoPageBox = addVBoxPage(i18n("Device Info"), i18n("Device Info"), KGlobal::iconLoader()->loadIcon("info", KIcon::NoGroup, 32) );
	QVBox *settingsPageBox = addVBoxPage(i18n("Settings"), i18n("K68 Settings"), KGlobal::iconLoader()->loadIcon("configure", KIcon::NoGroup, 32) );
	sendPage = new SendFile(obex, sendPageBox);
    infoPage = new DeviceInfo(obex, infoPageBox);
	settingsPage = new Settings(settingsPageBox);

	// Connect signals/slots
	connect(settingsPage, SIGNAL(settingsChanged()), this, SLOT(slotNewSettings()));
	connect(this, SIGNAL(aboutToShowPage(QWidget*)), this, SLOT(slotChangePage(QWidget*)));

	// Create the menu
	KPopupMenu *helpMenu = new KPopupMenu(this);

	// Create the help menu
	KHelpMenu *helpMenu_ = new KHelpMenu(this, KGlobal::instance()->aboutData());

	// Create menu items
	KActionCollection *actionCollection = new KActionCollection(this);
	// KAction *helpContents = KStdAction::helpContents(helpMenu_, SLOT(appHelpActivated()), actionCollection);
	KAction *aboutK68 = KStdAction::aboutApp(helpMenu_, SLOT(aboutApplication()), actionCollection);
	KAction *aboutKDE = KStdAction::aboutKDE(helpMenu_, SLOT(aboutKDE()), actionCollection);

	// Plug the items into "help"
	// helpContents->plug( helpMenu );
	// helpMenu->insertSeparator();
	aboutK68->plug( helpMenu );
	aboutKDE->plug( helpMenu );

	// Attach menu to button
	QPushButton* helpbutton = actionButton(Help);
	helpbutton->setPopup(helpMenu);
}

K68::~K68() {
    delete obex;
}

void K68::slotNewSettings() {
	settingsChanged = true;
}

void K68::slotChangePage(QWidget* page) {
	if(page != settingsPage && settingsChanged) {

        // Reset obex
        delete obex;
        obex = createObex();

        // Update obex references
        sendPage->setObex(obex);
		infoPage->setObex(obex);
        
		settingsChanged = false;
	}
}

void K68::closeEvent(QCloseEvent* close) {
	kapp->config()->sync();
	close->accept();
}

QObex *K68::createObex() {

	QObex *obex;

    // Find out which transport we're using
	KConfig *config = kapp->config();
	config->setGroup(Settings::configGroup);
	QString tmp = config->readEntry(Settings::configTransport, Settings::configSerialCable);

	// Create new obex instance according to selected transport
#ifdef HAVE_BLUETOOTH
	if(tmp == Settings::configBluetooth) {

		// Read address
		config->setGroup(BluetoothSettings::configGroup);
		QString address = config->readEntry(BluetoothSettings::configAddress, BluetoothSettings::configAddressDefault);

		// Convert address from string
		bdaddr_t bda;
	    str2ba(address.latin1(), &bda);

		// Read channel
		int channel = config->readNumEntry(BluetoothSettings::configChannel, BluetoothSettings::configChannelDefault);

		// Create instance
		obex = new QObexBluetooth(BDADDR_ANY, &bda, channel);
	} else
#endif
	if(tmp == Settings::configInfrared) {
		// Read service
		config->setGroup(InfraredSettings::configGroup);
		QString service = config->readEntry(InfraredSettings::configService, InfraredSettings::configServiceDefault);

		// Create instance
		obex = new QObexInfrared(service);
	} else {
		// Read serial device and baud rate
		config->setGroup(SerialCableSettings::configGroup);
    	QString device = config->readEntry(SerialCableSettings::configDevice, SerialCableSettings::configDeviceDefault);
		int baud = config->readNumEntry(SerialCableSettings::configBaudRate, SerialCableSettings::configBaudDefault);

		// Create obex instance
		obex = new QObexSerialCable(device, baud);
	}

	return obex;
}


