/***************************************************************************
                          qobex.cpp  -  description
                             -------------------
    begin                : Tue Dec 10 2002
    copyright            : (C) 2002-2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qobex.h"
#include "qobexobject.h"

#include <qtimer.h>


QObex::QObex() {
}

QObex::~QObex() {
	OBEX_Cleanup(obex);
}

void QObex::request(QObexObject& obj) {
	OBEX_Request(obex, obj.object);
}

void QObex::transportDisconnect() {
	OBEX_TransportDisconnect(obex);
	delete notifier;
}

QString QObex::responseToQString(QObex::Response rsp) {

    // Get latin response string
    char *ptr = OBEX_ResponseToString(int(rsp));

    QString tmp(ptr);

    return tmp;
}

QByteArray* QObex::qStringToUnicode(const QString &src) {

    // Get latin string
    const char* orig = src.latin1();

    // Create array to hold unicode
    int length = 2 * (src.length() + 1);
    QByteArray* dst = new QByteArray(length);
    char* dst_array = dst->data();

    // Convert
    OBEX_CharToUnicode((uint8_t*) dst_array, (uint8_t*) orig, length);

    return dst;
}

void QObex::createNotifier() {
	int fd = OBEX_GetFD(obex);
	notifier = new QSocketNotifier(fd, QSocketNotifier::Read);
	connect(notifier, SIGNAL(activated(int)), this, SLOT(slotHandleInput(int)));
}

void QObex::handleEvent(obex_object_t* obj, int /* mode */, int event, int obex_cmd, int obex_rsp) {
    QObexObject object(obex, obj);
    
	switch(event) {
		case OBEX_EV_PROGRESS:
			emit progressMade();
			break;

		case OBEX_EV_ABORT:
			emit requestAborted();
			break;

		case OBEX_EV_REQDONE:
            emit requestDone(object, QObex::Command(obex_cmd), QObex::Response(obex_rsp));

            /* This is a hack to emulate the use of postEvent and
             * customEvent which don't appear to work */
            QTimer::singleShot(0, this, SLOT(slotIdle()));
            break;

		case OBEX_EV_LINKERR:
			emit linkError();
			break;

		case OBEX_EV_STREAMEMPTY:
			emit streamEmpty(object);
			break;

		default:
			// Unknown event - ignore for the mean time
			break;
	}
}

void QObex::slotHandleInput(int /* fd */) {
	OBEX_HandleInput(obex, 0);
}


void QObex::slotIdle() {
    emit idle();
}

extern "C" void QObex_handleEvent(obex_t *handle, obex_object_t *obj, int mode, int event, int obex_cmd, int obex_rsp) {

	// Retrieve pointer to QObex object stored in obex_t
	QObex *obex = (QObex *) OBEX_GetUserData(handle);

	// Call QObex to handle event
	obex->handleEvent(obj, mode, event, obex_cmd, obex_rsp);
}

