/***************************************************************************
                      qobexserialcable.cpp - description
                             -------------------
    begin                : Thu Dec 12 2002
    copyright            : (C) 2002 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qobexserialcable.h"

QObexSerialCable::QObexSerialCable(const QString& dev, int baud) : device(dev) {

	// Store connection settings
    ud.device = device.latin1();
	ud.fd = -1;
	ud.baud = baud;

    /* Attempt to apply HUPCL workaround
     * Success/failure is ignored for the time being */
    serial_unset_hupcl(ud.device);
    
   	// Initialise custom transport struct
	obex_ctrans_t ct;
    ct.connect = serial_connect;
	ct.disconnect = serial_disconnect;
	ct.listen = NULL;
	ct.write = serial_write;
	ct.handleinput = serial_handleinput;
	ct.customdata = &ud;

    // Initialize obex
    obex = OBEX_Init(OBEX_TRANS_CUSTOM, QObex_handleEvent, 0);

    // Register transport
	OBEX_RegisterCTransport(obex, &ct);

    // Store pointer to self for callbacks
    OBEX_SetUserData(obex, (void*) this);
}

QObexSerialCable::~QObexSerialCable() {
}

bool QObexSerialCable::transportConnect() {
	struct sockaddr saddr; // dummy paramater

	if(OBEX_TransportConnect(obex, &saddr, 0) < 0)
        return false;
 
	createNotifier();
    return true;
}

void QObexSerialCable::createNotifier() {
	notifier = new QSocketNotifier(ud.fd, QSocketNotifier::Read);
	connect(notifier, SIGNAL(activated(int)), this, SLOT(slotHandleInput(int)));
}





