/***************************************************************************
                          sender.cpp  -  description
                             -------------------
    begin                : Tue Apr 8 2003
    copyright            : (C) 2003 by James Stembridge
    email                : jstembridge@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "sender.h"
#include "qobexclientput.h"

#include <kdeversion.h>
#include <kmessagebox.h>

Sender::Sender(QObex *obex, const KURL &url, QWidget *parent,
			   const char *name, const QString &caption,
			   const QString &text, bool modal)
	: KProgressDialog(parent, name, caption, text, modal), error(false) {

	// Don't disappear straight away or close ourselves
    setMinimumDuration(0);
    setAutoClose(false);

	// OpenOBEX doesn't support "nice" abort so no cancel
	setAllowCancel(false);

    // Create client to perform push and connect signals
    client = new QObexClientPut(*obex, url.path());

    connect(client, SIGNAL(error(const QString&)), this, SLOT(slotClientError(const QString&)));
    connect(client, SIGNAL(info(const QString&)), this, SLOT(slotClientInfo(const QString &)));
	connect(client, SIGNAL(done()), this, SLOT(slotClientDone()));

	// Set up movement of progress bar
    KProgress* bar = progressBar();
    connect(client, SIGNAL(totalSize(int)), bar, SLOT(setTotalSteps(int)));
    connect(client, SIGNAL(progress(int)), bar, SLOT(setValue(int)));

	// Start client
    client->start();	
}

Sender::~Sender(){

}

void Sender::slotClientInfo(const QString& msg) {
	setLabel(msg);
}

void Sender::slotClientError(const QString& msg) {
	// Hide ourselves
	hide();

	// Display error message
    KMessageBox::error(this, msg);

	// Record that we're in an error state
	error = true;
}

void Sender::slotClientDone() {
	// We're done with the client
	client->deleteLater();

	// If we're in an error state destroy ourselves
	if(error)
		delayedDestruct();
}

